@@ -19,13 +19,6 @@
 
 #include "interfaces_debug.h"
 
-static QString createId()
-{
-    return QCoreApplication::instance()->applicationName() + QString::number(QCoreApplication::applicationPid());
-}
-
-Q_GLOBAL_STATIC_WITH_ARGS(QString, s_keyId, (createId()));
-
 DevicesModel::DevicesModel(QObject *parent)
     : QAbstractListModel(parent)
     , m_dbusInterface(new DaemonDbusInterface(this))
@@ -34,7 +27,7 @@ DevicesModel::DevicesModel(QObject *parent)
     connect(this, &QAbstractItemModel::rowsRemoved, this, &DevicesModel::rowsChanged);
     connect(this, &QAbstractItemModel::rowsInserted, this, &DevicesModel::rowsChanged);
 
-    connect(m_dbusInterface, SIGNAL(deviceAdded(QString)), this, SLOT(deviceAdded(QString)));
+    connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceAdded, this, &DevicesModel::deviceAdded);
     connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceVisibilityChanged, this, &DevicesModel::deviceUpdated);
     connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceRemoved, this, &DevicesModel::deviceRemoved);
 
@@ -43,7 +36,6 @@ DevicesModel::DevicesModel(QObject *parent)
     connect(watcher, &QDBusServiceWatcher::serviceRegistered, this, &DevicesModel::refreshDeviceList);
     connect(watcher, &QDBusServiceWatcher::serviceUnregistered, this, &DevicesModel::clearDevices);
 
-    // refresh the view, acquireDiscoveryMode if necessary
     setDisplayFilter(NoFilter);
 }
 
@@ -60,7 +52,6 @@ QHash<int, QByteArray> DevicesModel::roleNames() const
 
 DevicesModel::~DevicesModel()
 {
-    m_dbusInterface->releaseDiscoveryMode(*s_keyId);
 }
 
 int DevicesModel::rowForDevice(const QString &id) const
@@ -103,9 +94,8 @@ void DevicesModel::deviceRemoved(const QString &id)
     }
 }
 
-void DevicesModel::deviceUpdated(const QString &id, bool isVisible)
+void DevicesModel::deviceUpdated(const QString &id)
 {
-    Q_UNUSED(isVisible);
     int row = rowForDevice(id);
 
     if (row < 0) {
@@ -140,13 +130,9 @@ void DevicesModel::setDisplayFilter(int flags)
 {
     m_displayFilter = (StatusFilterFlag)flags;
 
-    const bool reachableNeeded = (m_displayFilter & StatusFilterFlag::Reachable);
-    if (reachableNeeded)
-        m_dbusInterface->acquireDiscoveryMode(*s_keyId);
-    else
-        m_dbusInterface->releaseDiscoveryMode(*s_keyId);
-
     refreshDeviceList();
+
+    Q_EMIT displayFilterChanged(flags);
 }
 
 void DevicesModel::refreshDeviceList()
@@ -192,17 +178,10 @@ void DevicesModel::receivedDeviceList(QDBusPendingCallWatcher *watcher)
 void DevicesModel::appendDevice(DeviceDbusInterface *dev)
 {
     m_deviceList.append(dev);
-    connect(dev, &OrgKdeKdeconnectDeviceInterface::nameChanged, this, &DevicesModel::nameChanged);
-}
-
-void DevicesModel::nameChanged(const QString &newName)
-{
-    Q_UNUSED(newName);
-    DeviceDbusInterface *device = static_cast<DeviceDbusInterface *>(sender());
-
-    Q_ASSERT(rowForDevice(device->id()) >= 0);
-
-    deviceUpdated(device->id(), true);
+    connect(dev, &OrgKdeKdeconnectDeviceInterface::nameChanged, this, [this, dev]() {
+        Q_ASSERT(rowForDevice(dev->id()) >= 0);
+        deviceUpdated(dev->id());
+    });
 }
 
 void DevicesModel::clearDevices()
@@ -239,7 +218,7 @@ QVariant DevicesModel::data(const QModelIndex &index, int role) const
     case NameModelRole:
         return device->name();
     case Qt::ToolTipRole: {
-        bool trusted = device->isTrusted();
+        bool trusted = device->isPaired();
         bool reachable = device->isReachable();
         QString status = reachable ? (trusted ? i18n("Device trusted and connected") : i18n("Device not trusted")) : i18n("Device disconnected");
         return status;
@@ -249,7 +228,7 @@ QVariant DevicesModel::data(const QModelIndex &index, int role) const
         if (device->isReachable()) {
             status |= StatusFilterFlag::Reachable;
         }
-        if (device->isTrusted()) {
+        if (device->isPaired()) {
             status |= StatusFilterFlag::Paired;
         }
         return status;
@@ -287,5 +266,7 @@ bool DevicesModel::passesFilter(DeviceDbusInterface *dev) const
     bool onlyPaired = (m_displayFilter & StatusFilterFlag::Paired);
     bool onlyReachable = (m_displayFilter & StatusFilterFlag::Reachable);
 
-    return !((onlyReachable && !dev->isReachable()) || (onlyPaired && !dev->isTrusted()));
+    return !((onlyReachable && !dev->isReachable()) || (onlyPaired && !dev->isPaired()));
 }
+
+#include "moc_devicesmodel.cpp"
