@@ -8,29 +8,22 @@
 
 #include <QDebug>
 
+#include "kcoreaddons_version.h"
 #include <KConfigGroup>
-#include <KPluginLoader>
 
 PluginModel::PluginModel(QObject *parent)
     : QAbstractListModel(parent)
 {
-
-    connect(this, &QAbstractItemModel::rowsInserted,
-            this, &PluginModel::rowsChanged);
-    connect(this, &QAbstractItemModel::rowsRemoved,
-            this, &PluginModel::rowsChanged);
-
-
-    beginResetModel();
-    m_plugins = KPluginLoader::findPlugins(QStringLiteral("kdeconnect/"));
-    endResetModel();
+    connect(this, &QAbstractItemModel::rowsInserted, this, &PluginModel::rowsChanged);
+    connect(this, &QAbstractItemModel::rowsRemoved, this, &PluginModel::rowsChanged);
+    m_plugins = KPluginMetaData::findPlugins(QStringLiteral("kdeconnect"));
 }
 
 PluginModel::~PluginModel()
 {
 }
 
-void PluginModel::setDeviceId(const QString& deviceId)
+void PluginModel::setDeviceId(const QString &deviceId)
 {
     if (deviceId == m_deviceId)
         return;
@@ -38,6 +31,8 @@ void PluginModel::setDeviceId(const QString& deviceId)
     m_deviceId = deviceId;
     DeviceDbusInterface *device = new DeviceDbusInterface(m_deviceId);
     m_config = KSharedConfig::openConfig(device->pluginsConfigFile());
+
+    Q_EMIT deviceIdChanged(deviceId);
 }
 
 QVariant PluginModel::data(const QModelIndex &index, int role) const
@@ -49,10 +44,9 @@ QVariant PluginModel::data(const QModelIndex &index, int role) const
     const KPluginMetaData &pluginEntry = m_plugins[index.row()];
 
     switch (role) {
-    case Qt::CheckStateRole:
-    {
+    case Qt::CheckStateRole: {
         const QString def = pluginEntry.isEnabledByDefault() ? QStringLiteral("true") : QStringLiteral("false");
-        return m_config->group("Plugins").readEntry(QStringLiteral("%1Enabled").arg(pluginEntry.pluginId()), def) == QStringLiteral("true");
+        return m_config->group(QStringLiteral("Plugins")).readEntry(QStringLiteral("%1Enabled").arg(pluginEntry.pluginId()), def) == QStringLiteral("true");
     }
     case Qt::DisplayRole:
         return pluginEntry.name();
@@ -60,9 +54,9 @@ QVariant PluginModel::data(const QModelIndex &index, int role) const
         return pluginEntry.iconName();
     case IdRole:
         return pluginEntry.pluginId();
-    case ConfigSourceRole:
-    {
-        const QString configFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kdeconnect/%1_config.qml").arg(pluginEntry.pluginId()));
+    case ConfigSourceRole: {
+        const QString configFile =
+            QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kdeconnect/%1_config.qml").arg(pluginEntry.pluginId()));
         if (configFile.isEmpty())
             return QUrl();
 
@@ -75,7 +69,6 @@ QVariant PluginModel::data(const QModelIndex &index, int role) const
     }
 }
 
-
 QHash<int, QByteArray> PluginModel::roleNames() const
 {
     QHash<int, QByteArray> roles = QAbstractItemModel::roleNames();
@@ -88,7 +81,6 @@ QHash<int, QByteArray> PluginModel::roleNames() const
     return roles;
 }
 
-
 bool PluginModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
     if (!index.isValid()) {
@@ -99,7 +91,7 @@ bool PluginModel::setData(const QModelIndex &index, const QVariant &value, int r
 
     if (role == Qt::CheckStateRole) {
         const KPluginMetaData &pluginEntry = m_plugins[index.row()];
-        m_config->group("Plugins").writeEntry(QStringLiteral("%1Enabled").arg(pluginEntry.pluginId()), value);
+        m_config->group(QStringLiteral("Plugins")).writeEntry(QStringLiteral("%1Enabled").arg(pluginEntry.pluginId()), value);
         ret = true;
     }
 
@@ -125,3 +117,5 @@ QString PluginModel::deviceId()
 {
     return m_deviceId;
 }
+
+#include "moc_pluginmodel.cpp"
