@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef MPRISREMOTEPLUGIN_H
-#define MPRISREMOTEPLUGIN_H
+#pragma once
 
 #include <QObject>
 
@@ -16,8 +15,7 @@
 #define PACKET_TYPE_MPRIS_REQUEST QStringLiteral("kdeconnect.mpris.request")
 #define PACKET_TYPE_MPRIS QStringLiteral("kdeconnect.mpris")
 
-class Q_DECL_EXPORT MprisRemotePlugin
-    : public KdeConnectPlugin
+class MprisRemotePlugin : public KdeConnectPlugin
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.mprisremote")
@@ -27,15 +25,13 @@ class Q_DECL_EXPORT MprisRemotePlugin
     Q_PROPERTY(int position READ position WRITE setPosition NOTIFY propertiesChanged)
     Q_PROPERTY(QStringList playerList READ playerList NOTIFY propertiesChanged)
     Q_PROPERTY(QString player READ player WRITE setPlayer)
-    Q_PROPERTY(QString nowPlaying READ nowPlaying NOTIFY propertiesChanged)
     Q_PROPERTY(QString title READ title NOTIFY propertiesChanged)
     Q_PROPERTY(QString artist READ artist NOTIFY propertiesChanged)
     Q_PROPERTY(QString album READ album NOTIFY propertiesChanged)
     Q_PROPERTY(bool canSeek READ canSeek NOTIFY propertiesChanged)
 
 public:
-    explicit MprisRemotePlugin(QObject* parent, const QVariantList &args);
-    ~MprisRemotePlugin() override;
+    using KdeConnectPlugin::KdeConnectPlugin;
 
     long position() const;
     int volume() const;
@@ -43,7 +39,6 @@ public:
     bool isPlaying() const;
     QStringList playerList() const;
     QString player() const;
-    QString nowPlaying() const;
     QString title() const;
     QString artist() const;
     QString album() const;
@@ -51,24 +46,23 @@ public:
 
     void setVolume(int volume);
     void setPosition(int position);
-    void setPlayer(const QString& player);
+    void setPlayer(const QString &player);
 
-    bool receivePacket(const NetworkPacket& np) override;
-    void connected() override {}
+    void receivePacket(const NetworkPacket &np) override;
     QString dbusPath() const override;
 
     Q_SCRIPTABLE void seek(int offset) const;
     Q_SCRIPTABLE void requestPlayerList();
-    Q_SCRIPTABLE void sendAction(const QString& action);
+    Q_SCRIPTABLE void sendAction(const QString &action);
+    // we don't want this to be exposed via dbus, right?
+    void requestAlbumArt(const QString &player, const QString &album_art_url);
 
 Q_SIGNALS:
     Q_SCRIPTABLE void propertiesChanged();
 
 private:
-    void requestPlayerStatus(const QString& player);
+    void requestPlayerStatus(const QString &player);
 
     QString m_currentPlayer;
-    QMap<QString, MprisRemotePlayer*> m_players;
+    QMap<QString, MprisRemotePlayer *> m_players;
 };
-
-#endif
