@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef REMOTESYSTEMVOLUMEPLUGIN_H
-#define REMOTESYSTEMVOLUMEPLUGIN_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@
 #define PACKET_TYPE_SYSTEMVOLUME QStringLiteral("kdeconnect.systemvolume")
 #define PACKET_TYPE_SYSTEMVOLUME_REQUEST QStringLiteral("kdeconnect.systemvolume.request")
 
-class Q_DECL_EXPORT RemoteSystemVolumePlugin : public KdeConnectPlugin
+class RemoteSystemVolumePlugin : public KdeConnectPlugin
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.remotesystemvolume")
@@ -22,10 +21,9 @@ class Q_DECL_EXPORT RemoteSystemVolumePlugin : public KdeConnectPlugin
     Q_PROPERTY(QString deviceId READ deviceId CONSTANT)
 
 public:
-    explicit RemoteSystemVolumePlugin(QObject *parent, const QVariantList &args);
-    ~RemoteSystemVolumePlugin() override;
+    using KdeConnectPlugin::KdeConnectPlugin;
 
-    bool receivePacket(const NetworkPacket &np) override;
+    void receivePacket(const NetworkPacket &np) override;
     void connected() override;
     QString dbusPath() const override;
 
@@ -46,5 +44,3 @@ Q_SIGNALS:
 private:
     QByteArray m_sinks;
 };
-
-#endif // REMOTESYSTEMVOLUMEPLUGIN_H
